/**
  ******************************************************************************
  * @file    usb_conf_template.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    16-January-2014
  * @brief   General low level driver configuration
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __USB_CONF__H__
#define __USB_CONF__H__

/* Includes ------------------------------------------------------------------*/
#include "stm32f0xx.h"
#include "stm32072b_eval.h"

/* Exported defines ----------------------------------------------------------*/
/* Select D+ pull up: internal or external */
#define INTERNAL_PULLUP

/* Define if Low power mode is enabled; it allows entering the device into STOP mode
    following USB Suspend event, and wakes up after the USB wakeup event is received. */
/* #define USB_DEVICE_LOW_PWR_MGMT_SUPPORT */

/* Select the USB clock source: CRS using HSI48 or System clock (should be at 48 MHz) */
#define USB_CLOCK_SOURCE_CRS
/* #define USB_CLOCK_SOURCE_PLL */

/* Endpoints used by the device */
#define EP_NUM	  (3) /* EP0 + EP1 for MSC IN + EP2 for MSC OUT */

/* Buffer table base address */
#define BTABLE_ADDRESS	  (0x00)

/* EP0, RX/TX buffers base address */
#define ENDP0_RX_ADDRESS    (0x18)
#define ENDP0_TX_ADDRESS    (0x58)

/* EP1, TX buffer base address */
#define MSC_IN_TX_ADDRESS     (0x98)

/* EP2, Rx buffer base address */
#define MSC_OUT_RX_ADDRESS    (0xD8)

/* Exported types ------------------------------------------------------------*/
/* Exported macros -----------------------------------------------------------*/
/* Exported variables --------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */

#endif /* __USB_CONF__H__ */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
